@@ -96,6 +96,10 @@ gok_key_lookup_shorter_label (char *str)
 		g_free (str);
 		str = "Left\nTab";
 	}
+	else if (!strcmp (str, "Sterling")) {
+		g_free (str);
+		str = "£";
+	}
 	else {
 		gint len;
 		gboolean prev_is_lower, is_upper;
@@ -604,6 +608,7 @@ void gok_key_delete (GokKey* pKey, GokKeyboard* pKeyboard, gboolean bDeleteButto
 		(bDeleteButton == TRUE))
 	{
 		gtk_widget_destroy (pKey->pButton);
+		pKey->pButton = NULL;
 	}
 	
 	/* delete all the outputs associated with the key */
@@ -612,6 +617,10 @@ void gok_key_delete (GokKey* pKey, GokKeyboard* pKeyboard, gboolean bDeleteButto
 	gok_output_delete_all (pKey->pOutputWrapperPost);
 
 	g_free (pKey);
+
+	gok_feedback_drop_refs (pKey);
+	gok_scanner_drop_refs (pKey);
+	gok_repeat_drop_refs (pKey);
 }
 
 /**
@@ -795,7 +804,11 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *)"repeat-next") == 0)
 	{
 		pKey->Type = KEYTYPE_REPEATNEXT;
-		pKey->Style = KEYSTYLE_NORMAL;
+		pKey->Style = KEYSTYLE_REPEATNEXT;
+		pKey->has_image = TRUE;
+		pKey->pImage = gok_keyimage_new (pKey, NULL);
+		pKey->pImage->type = IMAGE_TYPE_INDICATOR;
+		pKey->ComponentState.active = FALSE;
 	}
 	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *)"mouse") == 0)
 	{
@@ -1581,10 +1594,15 @@ void gok_key_set_button_name (GokKey* pKey)
 		strcpy (styleText, "StyleTextNormal");
 		break;
 
-	case KEYSTYLE_BRANCHGUIACTIONS:
 	case KEYSTYLE_PAGESELECTION:
+		strcpy (styleButton, "StyleButtonBranchPageSelection");
+		strcpy (styleText, "StyleTextNormal");
+		break;
+
+	case KEYSTYLE_BRANCHGUIACTIONS:
 	case KEYSTYLE_HYPERLINK:
 	case KEYSTYLE_EDIT:
+	case KEYSTYLE_REPEATNEXT:
 		strcpy (styleButton, "StyleButtonBranchGuiActions");
 		strcpy (styleText, "StyleTextNormal");
 		break;
@@ -1640,7 +1658,7 @@ void gok_key_set_button_name (GokKey* pKey)
 void
 gok_key_update_toggle_state (GokKey *pKey)
 {
-	if (pKey && GTK_IS_TOGGLE_BUTTON (pKey->pButton)) {
+	if (pKey && pKey->pButton && GTK_IS_TOGGLE_BUTTON (pKey->pButton)) {
 	        gboolean is_active = FALSE; 
 		if (pKey->ModifierName != NULL)
 			is_active = 
