@@ -363,29 +363,35 @@ gok_keyboard_add_keys_from_xkb_geom (GokKeyboard *pKeyboard, XkbDescPtr kbd)
 		}
 	}
 
-	/* add a repeat next key */
-	pKey = gok_key_new (pKey, NULL, pKeyboard);
-	pKey->Style = KEYSTYLE_NORMAL;
-	pKey->Type = KEYTYPE_REPEATNEXT;
-	pKey->Target = (gchar*)g_malloc (strlen("repeat-next") + 1);
-	strcpy (pKey->Target, "repeat-next");
-	pKey->Top = row + 1;
-	pKey->Bottom = row + 2;
-	pKey->Left = 0;
-	pKey->Right = 3;
-	gok_key_add_label (pKey, _("Repeat Next Key"),NULL);
-
-	/* add a branch key for special text edit functions */
-	pKey = gok_key_new (pKey, NULL, pKeyboard);
-	pKey->Style = KEYSTYLE_GENERALDYNAMIC;
-	pKey->Type = KEYTYPE_BRANCHCOMPOSE;
-	pKey->Target = (gchar*)g_malloc (strlen("text-operations") + 1);
-	strcpy (pKey->Target, "text-operations");
-	pKey->Top = row + 1;
-	pKey->Bottom = row + 2;
-	pKey->Left = 3;
-	pKey->Right = rightmost;
-	gok_key_add_label (pKey, _("Text Manipulation"),NULL);
+	if (!gok_main_get_login ()) {
+		/* add a repeat next key */
+		pKey = gok_key_new (pKey, NULL, pKeyboard);
+		pKey->Style = KEYSTYLE_REPEATNEXT;
+		pKey->Type = KEYTYPE_REPEATNEXT;
+		pKey->has_image = TRUE;
+		pKey->pImage = gok_keyimage_new (pKey, NULL);
+		pKey->pImage->type = IMAGE_TYPE_INDICATOR;
+		pKey->ComponentState.active = FALSE;
+		pKey->Target = (gchar*)g_malloc (strlen("repeat-next") + 1);
+		strcpy (pKey->Target, "repeat-next");
+		pKey->Top = row + 1;
+		pKey->Bottom = row + 2;
+		pKey->Left = 0;
+		pKey->Right = 3;
+		gok_key_add_label (pKey, _("Repeat Next Key"),NULL);
+		
+		/* add a branch key for special text edit functions */
+		pKey = gok_key_new (pKey, NULL, pKeyboard);
+		pKey->Style = KEYSTYLE_GENERALDYNAMIC;
+		pKey->Type = KEYTYPE_BRANCHCOMPOSE;
+		pKey->Target = (gchar*)g_malloc (strlen("text-operations") + 1);
+		strcpy (pKey->Target, "text-operations");
+		pKey->Top = row + 1;
+		pKey->Bottom = row + 2;
+		pKey->Left = 3;
+		pKey->Right = rightmost;
+		gok_key_add_label (pKey, _("Text Manipulation"),NULL);
+	}
 }
 
 Display *
@@ -410,18 +416,21 @@ gok_keyboard_get_core ()
 	gok_keyboard_set_name (pKeyboard, CORE_KEYBOARD);
 	pKeyboard->bRequiresLayout = FALSE;
 	pKeyboard->bLaidOut = TRUE;
-	pKeyboard->bSupportsWordCompletion = TRUE;
+	pKeyboard->bSupportsWordCompletion = FALSE;
 	pKeyboard->bSupportsCommandPrediction = FALSE;
-	pKey = gok_key_new (NULL, NULL, pKeyboard);
-	pKey->Type = KEYTYPE_BRANCHBACK;
-	pKey->Style = KEYSTYLE_BRANCHBACK;
-	pKey->FontSize = -1;
-	pKey->FontSizeGroup = FONT_SIZE_GROUP_UNIQUE;
-	pKey->Top = 0;
-	pKey->Bottom = 1;
-	pKey->Left = 0;
-	pKey->Right = 1;
-	gok_keylabel_new (pKey, _("Back"), NULL);
+	if (!gok_main_get_login ()) {
+		pKeyboard->bSupportsWordCompletion = TRUE;
+		pKey = gok_key_new (NULL, NULL, pKeyboard);
+		pKey->Type = KEYTYPE_BRANCHBACK;
+		pKey->Style = KEYSTYLE_BRANCHBACK;
+		pKey->FontSize = -1;
+		pKey->FontSizeGroup = FONT_SIZE_GROUP_UNIQUE;
+		pKey->Top = 0;
+		pKey->Bottom = 1;
+		pKey->Left = 0;
+		pKey->Right = 1;
+		gok_keylabel_new (pKey, _("Back"), NULL);
+	}
 	gok_keyboard_add_keys_from_xkb_geom (pKeyboard, 
 					     gok_keyboard_get_xkb_desc ());
 	gok_keyboard_count_rows_columns (pKeyboard);
@@ -1335,14 +1344,20 @@ gboolean gok_keyboard_display (GokKeyboard* pKeyboard, GokKeyboard* pKeyboardCur
 			if (pKey->Type == KEYTYPE_MODIFIER) {
 				GOK_BUTTON (pNewButton)->indicator_type = "shift";
 			}
+			else if (pKey->Type == KEYTYPE_REPEATNEXT) {
+			        GOK_BUTTON (pNewButton)->indicator_type = "checkbox";
+			}
 
 			/* associate the button with the key */
 			pKey->pButton = pNewButton;
 			gtk_object_set_data (GTK_OBJECT(pNewButton), "key", pKey);
 
 			/* set the initial state of the button from pKey state*/
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pNewButton),
-						      pKey->ComponentState.active);
+			if (pNewButton && GTK_IS_TOGGLE_BUTTON (pNewButton))
+			{
+			        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pNewButton),
+							      pKey->ComponentState.active);
+			}
 
 			/* add these signal handlers to the button */
 			if (CallbackScanner == TRUE) /* button is used by GOK */
@@ -2773,7 +2788,10 @@ GokKey* gok_keyboard_output_key(GokKey* pKey)
 			break;*/
 		
 		case KEYTYPE_REPEATNEXT:
-			gok_repeat_arm();
+			if (pKey->pButton && GTK_IS_TOGGLE_BUTTON (pKey->pButton))
+			{
+			      gok_repeat_toggle_armed (pKey);
+			}
 			pKey = NULL; /* useful hack */
 			break;
 				
@@ -2806,11 +2824,14 @@ GokKey* gok_keyboard_output_key(GokKey* pKey)
 		case KEYTYPE_BRANCHTEXT:
 			if (pKey->pNodeAccessible && 
 				pKey->pNodeAccessible->paccessible) {
-					gok_keyboard_focus_object 
-						(pKey->pNodeAccessible->paccessible);
-				}
-			gok_main_display_scan ( NULL, "Keyboard", 
-					KEYBOARD_TYPE_UNSPECIFIED, KEYBOARD_LAYOUT_NORMAL);
+					if (gok_keyboard_focus_object 
+						(pKey->pNodeAccessible->paccessible))
+					{
+						gok_main_display_scan ( NULL, "Keyboard", 
+									KEYBOARD_TYPE_UNSPECIFIED, 
+									KEYBOARD_LAYOUT_NORMAL);
+					}
+			}
 			break;
 
 		case KEYTYPE_SETTINGS:
