@@ -211,9 +211,9 @@ void gok_output_send_to_system (GokOutput* pOutput, gboolean bWordCompletion)
 			SPI_generateKeyboardEvent ((long) keysym, NULL, SPI_KEY_SYM);
 
 			/* update the word prediction keys with the new output */
-			if (bWordCompletion == TRUE)
-			{
-				gok_wordcomplete_predict (gok_output_unichar_from_keysym (keysym));
+			if (bWordCompletion && !gok_main_get_login()) {
+					gok_wordcomplete_predict (
+						gok_output_unichar_from_keysym (keysym));
 			}
 		}
 		else if (pOutput->Type == OUTPUT_KEYCODE)
@@ -226,7 +226,7 @@ void gok_output_send_to_system (GokOutput* pOutput, gboolean bWordCompletion)
 
 			SPI_generateKeyboardEvent ((long) keycode, NULL, pOutput->Flag);
 			/* update the word prediction keys with the new output */
-			if (bWordCompletion == TRUE && 
+			if (bWordCompletion && !gok_main_get_login() &&
 			    !gok_key_modifier_for_keycode (
 				    gok_main_display (),
 				    gok_keyboard_get_xkb_desc (),
