@@ -76,8 +76,10 @@
 #define GOK_ERROR_ACTION_OPEN         6
 #define GOK_ERROR_FEEDBACK_OPEN       7
 #define GOK_ERROR_NO_XKB_EXTENSION    8
+#define GOK_ERROR_NOSTICKYKEYS		  9
 
 #define GOKMAINKEYBOARDNAME "main"
+#define GOKLOGINKEYBOARDNAME "Keyboard"
 
 #define KEYBOARD_ACCESSIBILITY_STICKY_KEYS_KEY "/desktop/gnome/accessibility/keyboard/stickykeys_enable"
 #define GCONF_ACCESSIBILITY_KEY "/desktop/gnome/interface/accessibility"
@@ -188,7 +190,6 @@ static struct poptOption options[] = {
 		N_("KEYBOARDNAME")
 	},
 	{
-		/* TODO: NOT USED */
 		"login", 
 		'l', 
 		POPT_ARG_NONE, 
@@ -273,7 +274,7 @@ gint main (gint argc, gchar *argv[])
 	}
 	
 	gok_spy_add_idle_handler ();
-
+	
 	/* start the main hook */
 	SPI_event_main();	
 
@@ -431,9 +432,11 @@ gint gok_main_open(gint argc, gchar *argv[])
 	gok_chunker_initialize();
 	gok_keyboard_initialize();
 	gok_branchbackstack_initialize();
-	gok_main_initialize_wordcomplete ();
 	
-	gok_main_initialize_commandprediction ();
+	if (!bLoginOption) {
+		gok_main_initialize_wordcomplete ();
+		gok_main_initialize_commandprediction ();
+	}
 	
 	/* create the settings dialog */
 	if (gok_settingsdialog_open (bDisplaySettingsDialog) == FALSE)
@@ -442,21 +445,46 @@ gint gok_main_open(gint argc, gchar *argv[])
 		return GOK_ERROR_SETTINGSDIALOG_OPEN;
 	}
 
-	if (mainkeyboardname == NULL)
-	{
-		mainkeyboardname = (gchar*) g_malloc (strlen (GOKMAINKEYBOARDNAME) + 1);
-		strcpy (mainkeyboardname, (gchar *) GOKMAINKEYBOARDNAME);
+
+	/* a specified keyboard takes precedance, even if the login flag is specifed
+	   we use the login keyboard, otherwise the regular main keyboard */
+	if (mainkeyboardname == NULL) {
+		if (bLoginOption) {
+			mainkeyboardname = (gchar*) 
+				g_malloc (strlen (GOKLOGINKEYBOARDNAME) + 1);
+			strcpy (mainkeyboardname, (gchar *) GOKLOGINKEYBOARDNAME);
+		}
+		else {
+			mainkeyboardname = (gchar*) 
+				g_malloc (strlen (GOKMAINKEYBOARDNAME) + 1);
+			strcpy (mainkeyboardname, (gchar *) GOKMAINKEYBOARDNAME);
+		}
+	}
+
+	if (!bLoginOption) {
+		gok_main_check_accessibility();
 	}
 	
+	if (!gok_main_check_sticky_keys (m_pWindowMain)) {
+		return GOK_ERROR_NOSTICKYKEYS;
+	}
 
-	gok_main_check_accessibility();
-	
 	/* display the "main" keyboard */
 	if (gok_main_display_scan_main () == FALSE)
 	{
 		return GOK_ERROR_DISPLAY_SCAN_MAIN;
 	}
 
+gok_log ("check for currently active frame");
+	if (m_pForegroundWindowAccessible == NULL) {
+		/* check for currently active frame */
+		Accessible* accessible;
+		accessible = gok_spy_get_active_frame();
+		if (accessible)
+			gok_main_window_change_listener (accessible);
+	}
+gok_log ("finished check");
+	
 	/* connect signal handlers; don't trap SIGKILL */ 
 	signal(SIGSEGV, (void (*)(int))gok_sig_handler);
 	signal(SIGTERM, (void (*)(int))gok_sig_handler);
@@ -590,34 +618,32 @@ void gok_main_window_change_listener (Accessible* pAccessible)
 	GokKeyboard* pKeyboard = NULL;
 
 	gok_log_enter();	
-	if (1) /* TODO check to make sure the new window is not the gok window! */
-	{
-		/* note: ref counting happens in gok-spy's listeners */
-	        m_pForegroundWindowAccessible = pAccessible;
-		
-		/* we might currently have a dynamic keyboard so we need to branch to be safe */
-		gok_main_display_scan_previous_premade();
-		
-		/*if (*/gok_keyboard_validate_dynamic_keys (pAccessible);/* == TRUE)*/
-		{
-			/* rechunk the keyboard because keys have changed state */
-			gok_scanner_stop();
-			pKeyboard = gok_main_get_current_keyboard();
-			
-			gok_chunker_chunk (pKeyboard);
-			pKeyboard->bRequiresChunking = FALSE;
-		
-			/* highlight the first chunk */
-			gok_chunker_highlight_first_chunk();
-			
-			/* restart the scanning process */
-			gok_scanner_start();
-		}
 
-		/* hack to make sure gok is not occluded - seems to be unstable*/
-		gdk_window_raise (m_pWindowMain->window);
+	/* note: ref counting happens in gok-spy's listeners */
+	m_pForegroundWindowAccessible = pAccessible;
+	
+	/* we might currently have a dynamic keyboard so we need to branch to be safe */
+	gok_main_display_scan_previous_premade();
+	
+	/*if (*/gok_keyboard_validate_dynamic_keys (pAccessible);/* == TRUE)*/
+	{
+		/* rechunk the keyboard because keys have changed state */
+		gok_scanner_stop();
+		pKeyboard = gok_main_get_current_keyboard();
+		
+		gok_chunker_chunk (pKeyboard);
+		pKeyboard->bRequiresChunking = FALSE;
+	
+		/* highlight the first chunk */
+		gok_chunker_highlight_first_chunk();
+		
+		/* restart the scanning process */
+		gok_scanner_start();
 	}
 
+	/* hack to make sure gok is not occluded - seems to be unstable*/
+	gdk_window_raise (m_pWindowMain->window);
+
 	gok_log_leave();	
 }
 
@@ -2019,17 +2045,19 @@ gok_main_check_sticky_keys (GtkWidget *widget)
 						      XkbStickyKeysMask)) {
 #endif
 				xkb_ok = TRUE;
-				dialog = gtk_message_dialog_new (GTK_WINDOW (widget),
+				if (!bLoginOption) {
+				  dialog = gtk_message_dialog_new (GTK_WINDOW (widget),
 								 GTK_DIALOG_DESTROY_WITH_PARENT,
 								 GTK_MESSAGE_INFO,
 								 GTK_BUTTONS_OK,
 								 "GOK has enabled Sticky Keys, which it requires.\n");
 				
-				/* Destroy the dialog when the user responds to it (e.g. clicks a button) */
-				g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
+				  /* Destroy the dialog when the user responds to it (e.g. clicks a button) */
+				  g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
 							  G_CALLBACK (gtk_widget_destroy),
 							  GTK_OBJECT (dialog));
-				gtk_widget_show_all (dialog);
+				  gtk_widget_show_all (dialog);
+				}
 			}
 			else
 				xkb_ok = FALSE;
@@ -2037,16 +2065,18 @@ gok_main_check_sticky_keys (GtkWidget *widget)
 		XkbFreeKeyboard (xkb, 0, True);
 	}
 	if (xkb_ok == FALSE) {
+		if (!bLoginOption) {
                 /* post an error dialog */
-		dialog = gtk_message_dialog_new (GTK_WINDOW (widget),
+			dialog = gtk_message_dialog_new (GTK_WINDOW (widget),
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_CLOSE,
 						 "GOK cannot run because XKB display extension is missing.\n");		
-		g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
+			g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
 					  G_CALLBACK (gtk_widget_destroy),
 					  GTK_OBJECT (dialog));
-		gtk_widget_show_all (dialog);
+			gtk_widget_show_all (dialog);
+		}
 		return FALSE;
 	}
 	return TRUE;
